@@ -55,8 +55,6 @@ def module_contains_display(expression):
     except AttributeError:
         contains_display_attr = False
     contains_display_func = False
-    print(expression.func.name)
-    contains_display_func = expression.func.name == "display"
     for arg in expression.value.args:
         if isinstance(arg.parent, astroid.nodes.Call):
             print(arg.parent.func)
@@ -77,8 +75,8 @@ def module_contains_show(expression):
         contains_show_attr = False
     contains_show_func = False
     for arg in expression.value.args:
-        if isinstance(arg, astroid.nodes.Call):
-            if arg.func.attrname == "show":
+        if isinstance(arg.parent, astroid.nodes.Call):
+            if arg.parent.func.name == "show":
                 contains_show_func = True
     return (contains_func_attribute and contains_attrname and contains_show_attr) or (
         contains_func_attribute and contains_show_func
@@ -94,8 +92,8 @@ def module_contains_print(expression):
     #     contains_display_attr = False
     contains_print_func = False
     for arg in expression.value.args:
-        if isinstance(arg, astroid.nodes.Call):
-            if arg.func.attrname == "print":
+        if isinstance(arg.parent, astroid.nodes.Call):
+            if arg.parent.func.name == "print":
                 contains_print_func = True
     return contains_func_attribute and contains_print_func
 
